<?php

namespace App\Filament\Resources;

use App\Filament\Resources\CartResource\Pages;
use App\Filament\Resources\CartResource\RelationManagers;
use App\Models\Cart;
use Filament\Forms;
use Filament\Resources\Form;
use Filament\Resources\Resource;
use Filament\Resources\Table;
use Filament\Tables;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;

class CartResource extends Resource
{
    protected static ?string $model = Cart::class;

    protected static ?string $navigationIcon = 'heroicon-o-shopping-cart';

    public static function getModelLabel(): string
    {
        return '购物车'; // TODO: Change the autogenerated stub
    }

    public static function form(Form $form): Form
    {
        return $form
            -> schema([
                Forms\Components\TextInput ::make('session_id')
                    -> required()
                    -> maxLength(255),
                Forms\Components\TextInput ::make('product_id')
                    -> required(),
                Forms\Components\TextInput ::make('jian')
                    -> maxLength(255),
                Forms\Components\TextInput ::make('brand')
                    -> maxLength(40),
                Forms\Components\TextInput ::make('numbers')
                    -> required(),
                Forms\Components\TextInput ::make('singletotal')
                    -> required(),
                Forms\Components\TextInput ::make('baseprice')
                    -> required(),
                Forms\Components\TextInput ::make('ip')
                    -> required()
                    -> maxLength(45),
                Forms\Components\Toggle ::make('is_buy')
                    -> required(),
            ]);
    }

    public static function table(Table $table): Table
    {
        return $table
            -> columns([
                Tables\Columns\TextColumn ::make('session_id'),
                Tables\Columns\TextColumn ::make('product_id'),
                Tables\Columns\TextColumn ::make('jian'),
                Tables\Columns\TextColumn ::make('brand'),
                Tables\Columns\TextColumn ::make('numbers'),
                Tables\Columns\TextColumn ::make('singletotal'),
                Tables\Columns\TextColumn ::make('baseprice'),
                Tables\Columns\TextColumn ::make('ip'),
                Tables\Columns\IconColumn ::make('is_buy')
                    -> boolean(),
                Tables\Columns\TextColumn ::make('updated_at')
                    -> dateTime(),
                Tables\Columns\TextColumn ::make('created_at')
                    -> dateTime(),
            ])
            -> filters([
                //
            ])
            -> actions([
                Tables\Actions\EditAction ::make(),
            ])
            -> bulkActions([
                Tables\Actions\DeleteBulkAction ::make(),
            ]);
    }

    public static function getRelations(): array
    {
        return [
            //
        ];
    }

    public static function getPages(): array
    {
        return [
            'index' => Pages\ListCarts ::route('/'),
            'create' => Pages\CreateCart ::route('/create'),
            'edit' => Pages\EditCart ::route('/{record}/edit'),
        ];
    }
}
