<?php

namespace App\Filament\Resources;

use App\Filament\Resources\PaypalResource\Pages;
use App\Filament\Resources\PaypalResource\RelationManagers;
use App\Models\Paypal;
use Filament\Forms;
use Filament\Resources\Form;
use Filament\Resources\Resource;
use Filament\Resources\Table;
use Filament\Tables;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;

class PaypalResource extends Resource
{
    protected static ?string $model = Paypal::class;

    protected static ?string $navigationIcon = 'heroicon-o-collection';

    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                Forms\Components\TextInput::make('session_id')
                    ->required()
                    ->maxLength(191),
                Forms\Components\TextInput::make('trans_id')
                    ->required()
                    ->maxLength(32),
                Forms\Components\TextInput::make('payer_id')
                    ->required()
                    ->maxLength(255),
                Forms\Components\TextInput::make('local_id')
                    ->required()
                    ->maxLength(255),
                Forms\Components\TextInput::make('order_id')
                    ->maxLength(255),
                Forms\Components\TextInput::make('name')
                    ->required()
                    ->maxLength(30),
                Forms\Components\TextInput::make('phone')
                    ->tel()
                    ->required()
                    ->maxLength(30),
                Forms\Components\TextInput::make('email')
                    ->email()
                    ->required()
                    ->maxLength(191),
                Forms\Components\TextInput::make('postal')
                    ->required()
                    ->maxLength(191),
                Forms\Components\TextInput::make('country')
                    ->required()
                    ->maxLength(30),
                Forms\Components\TextInput::make('state')
                    ->required()
                    ->maxLength(191),
                Forms\Components\TextInput::make('city')
                    ->required()
                    ->maxLength(191),
                Forms\Components\TextInput::make('street1')
                    ->required()
                    ->maxLength(191),
                Forms\Components\TextInput::make('street2')
                    ->maxLength(191),
                Forms\Components\TextInput::make('ip')
                    ->required()
                    ->maxLength(45),
                Forms\Components\TextInput::make('total')
                    ->required(),
                Forms\Components\TextInput::make('currency')
                    ->required()
                    ->maxLength(255),
                Forms\Components\Textarea::make('des')
                    ->maxLength(65535),
            ]);
    }

    public static function table(Table $table): Table
    {
        return $table
            ->columns([
                Tables\Columns\TextColumn::make('session_id'),
                Tables\Columns\TextColumn::make('trans_id'),
                Tables\Columns\TextColumn::make('payer_id'),
                Tables\Columns\TextColumn::make('local_id'),
                Tables\Columns\TextColumn::make('order_id'),
                Tables\Columns\TextColumn::make('name'),
                Tables\Columns\TextColumn::make('phone'),
                Tables\Columns\TextColumn::make('email'),
                Tables\Columns\TextColumn::make('postal'),
                Tables\Columns\TextColumn::make('country'),
                Tables\Columns\TextColumn::make('state'),
                Tables\Columns\TextColumn::make('city'),
                Tables\Columns\TextColumn::make('street1'),
                Tables\Columns\TextColumn::make('street2'),
                Tables\Columns\TextColumn::make('ip'),
                Tables\Columns\TextColumn::make('total'),
                Tables\Columns\TextColumn::make('currency'),
                Tables\Columns\TextColumn::make('created_at')
                    ->dateTime(),
                Tables\Columns\TextColumn::make('des'),
            ])
            ->filters([
                //
            ])
            ->actions([
                Tables\Actions\EditAction::make(),
            ])
            ->bulkActions([
                Tables\Actions\DeleteBulkAction::make(),
            ]);
    }
    
    public static function getRelations(): array
    {
        return [
            //
        ];
    }
    
    public static function getPages(): array
    {
        return [
            'index' => Pages\ListPaypals::route('/'),
            'create' => Pages\CreatePaypal::route('/create'),
            'edit' => Pages\EditPaypal::route('/{record}/edit'),
        ];
    }    
}
