<?php

namespace App\Filament\Widgets;

use App\Models\Cart;
use App\Models\Order;
use Filament\Widgets\LineChartWidget;
use Flowframe\Trend\Trend;
use Flowframe\Trend\TrendValue;
use Illuminate\Support\Facades\Cache;

class OrderChart extends LineChartWidget
{
    protected static ?string $heading = 'Chart';
    public ?string $filter = 'week';
    protected static ?string $pollingInterval = null;
    protected static string $name = 'order';

    protected function getFilters(): ?array
    {
        return [
            'today' => 'Today',
            'week' => 'this week',
            'month' => 'last month',
            'year' => 'This year',
        ];
    }

    protected function getData(): array
    {

        $activeFilter = $this -> filter;
        $cacheName = static ::$name . $activeFilter;
        if (Cache ::has($cacheName)) {
            $data = Cache::get($cacheName);
        }else{
            $query = Trend ::model(Order::class);

            $data = $query
                -> count();
            Cache::put($cacheName,$data,86400);
        }


        return [
            'datasets' => [
                [
                    'label' => '订单数量',
                    'backgroundColor' => 'rgb(255, 99, 132)',
                    'data' => $data -> map(fn(TrendValue $value) => $value -> aggregate),
                ],
            ],
            'labels' => $data -> map(fn(TrendValue $value) => $value -> date),
        ];
    }
}
