<?php

namespace App\Filament\Widgets\trait;

use Illuminate\Support\Facades\DB;

trait WidgetHandle
{
    protected function getFilters(): ?array
    {
        return [
            'today' => 'Today',
            'week' => 'this week',
            'month' => 'last month',
            'year' => 'This year',
        ];
    }

    /**
     *处理时间和模型查询
     **/
    public function handleQuery(string $activeFilter, object $query): object
    {
        switch ($activeFilter) {
            case 'today':
                $query -> between(
                    start: now() -> startOfDay(),
                    end: now() -> endOfDay(),
                ) -> perHour();
                break;
            case 'week':
                $query -> between(
                    start: now() -> subWeek(),
                    end: now(),
                ) -> perDay();
                break;
            case 'month':
                $query -> between(
                    start: now() -> startOfMonth() -> subMonth(),
                    end: now(),
                ) -> perDay();
                break;
            case 'year':
                $query -> between(
                    start: now() -> startOfYear() -> subYear(),
                    end: now(),
                ) -> perMonth();
        }
        return $query;
    }

    public function betweenTime(string $filter, \Illuminate\Database\Eloquent\Builder $query): object
    {
        $column = "";
        $between = '';
        switch ($filter) {
            case 'today':
                $column = "date_format(created_at,'%h')as days";
                $between = [
                    now() -> startOfDay(),
                    now() -> endOfDay(),
                ];
                break;
            case 'week':
                $column = "date_format(created_at,'%W')as days";
                $between = [
                    now() -> startOfWeek()->subWeek(),
                    now(),
                ];
                break;
            case 'month':
                $column = "date_format(created_at,'%Y-%m-%d')as days";
                $between = [
                    now() -> startOfMonth() -> subMonth(),
                    now(),
                ];
                break;
            case 'year':
                $column = "date_format(created_at,'%m')as days";
                $between = [
                    now() -> startOfYear() -> subYear(),
                    now(),
                ];
        }
        return $query ->select(DB::raw($column))-> whereBetween('created_at', $between);
    }

}
