<?php

namespace App\Http\Controllers;

use App\Models\Category;
use App\Models\Product;
use App\Models\Service\ProductService;
use Illuminate\Http\Request;

class CategoriesController extends Controller
{
    /**
     *分类
     *
     **/
    public function category(Request $request)
    {
        $id = $request -> id;
        $category = Category ::query() -> findOrFail($id);
        $brands = Product ::query() -> withoutGlobalScope('stock')
            -> selectRaw('cs,max(category1)as category1,count(cs) as nums')
            -> where('category1', $category -> id) -> groupBy('cs')
            -> orderBy('cs', 'asc')
            -> get();
        return view('categories.category', compact('brands', 'category'));
    }

    public function all()
    {
        $categories = Category::query()->where('category_es','!=','')->get();
        return view('categories.all',compact('categories'));
    }

    /**
     *
     *品牌页面
     **/
    public function brand(Request $request)
    {
        /**
         * @var int    $id      分类category id
         * @var string $brand   cs
         * @var  int   $perPage 分页每页个数
         *
         **/
        $id = $request -> id;
        $brand = $request -> brand;
        $perPage = $request -> perPage ?? 20;
        $order = $request -> order;

        $category = Category ::query() -> findOrFail($id);
        $products = Product ::query() -> withoutGlobalScope('stock')
            -> where('pprice_eu', '>', 0)
            -> where('stock', 'ok')
            -> where('category1', $id)
            -> where('cs', $brand)
            -> order($order)
            -> paginate($perPage);
        $products -> appends([
            'perPage' => $perPage,
            'order' => $order
        ]);
        return view('categories.brand', compact('category', 'products', 'perPage', 'order', 'brand'));
    }

    /**
     *新产品
     *
     **/
    public function new(Request $request)
    {
        $page = $request -> page ?? 1;
        $perPage = 20;
        $options = [
            'path' => $request -> url()
        ];
        $products = app(ProductService::class) -> getNewProducts(100, true, $page, $perPage, $options);
        return view('categories.new', compact('products'));
    }

    public function hot(Request $request)
    {
        $page = $request -> page ?? 1;
        $perPage = 20;
        $options = [
            'path' => $request -> url()
        ];
        $products = app(ProductService::class) -> getHotProducts(100, true, $page, $perPage, $options);
        return view('categories.hot', compact('products'));

    }
}
