<?php

namespace App\Http\Controllers;

use App\Jobs\CheckOrderJob;
use App\Models\Cart;
use App\Models\Product;
use App\Models\Service\PaypalService;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;
use Srmklive\PayPal\Services\PayPal as PayPalClient;

class PaypalController extends Controller
{
    protected $service;
    protected $provider;

    public function __construct(PaypalService $service)
    {
        $this -> service = $service;
    }

    /**
     * @note paypal创建订单
     *
     **/
    public function processTransaction(Request $request)
    {
        $data = $request->all();
        $request->validate([
            'name'=>'required|min:2',
            'phone'=>'required',
            'email'=>'required|email',
            'postal'=>'required',
            'state'=>'required',
            'city'=>'required',
            'address1'=>'required',
            'country'=>'required'
        ]);
        $userId = session() -> getId();
        $data = $this -> service -> createConfigData($userId,$data);
        $provider = new PayPalClient();
        $paypalToken = $provider -> getAccessToken();
        $response = $provider -> createOrder($data);
        dispatch(new CheckOrderJob($response['id'], $userId)) -> delay(now() -> addMinutes(1));
        if (isset($response['id']) && $response['id'] != null) {
            // redirect to approve href
            foreach ($response['links'] as $links) {
                if ($links['rel'] == 'approve') {
                    return redirect() -> away($links['href']);
                }
            }
            return redirect()
                -> route('payFail')
                -> with('error', 'Something went wrong.');
        } else {
            return redirect()
                -> route('payFail')
                -> with('error', $response['message'] ?? 'Something went wrong.');
        }
    }


    /**
     *  paypal 创建订单成功捕获订单
     *
     **/
    public function successTransaction(Request $request)
    {
        /**
         * @var string $token paypal token
         *
         **/
        $token = $request -> token;
        $userId = session() -> getId();
        $provider = new PayPalClient();
        $provider -> setApiCredentials(config('paypal'));
        $provider -> getAccessToken();
        $response = $provider -> capturePaymentOrder($token);
        if (isset($response['status']) && $response['status'] == 'COMPLETED') {
            //处理paypal返回的数据，信息入库
            $this -> service -> handleResponse($response, $userId);
            return redirect()
                -> route('paySuccess')
                -> with('success', 'Transaction complete.');
        } else {
            return redirect()
                -> route('payFail')
                -> with('error', $response['message'] ?? 'Something went wrong.');
        }
    }

    /**
     * cancel transaction.
     *取消支付
     *
     */
    public function cancelTransaction(Request $request)
    {
        $provider = new PayPalClient();
        $token = $provider -> getAccessToken();
        $order = $provider -> showOrderDetails($request -> token);
        $items = $order['purchase_units'][0]['items'];
//        foreach ($items as $item) {
//            $product = Product ::query() -> where('pcode', $item['sku']) -> first();
//            $product = $this -> service -> createProduct($product);
//            $product_id = 'PROD-61N21842R7819783A';
//            $paypalProduct = $provider -> showProductDetails($product_id);
//            $data = $this->service->updateProduct($product);
//            $requestId = 'create-product-' . $item['sku'] . '-' . time();
//            $update = $provider -> updateProduct($product_id, $data);
////            $create = $provider -> createProduct($product, $requestId);
//        }

    }

    /**
     *
     *支付表单
     **/
    public function form()
    {
        $total = 0;
        $carts = Cart ::query()
            -> with('product')
            -> where('session_id', session() -> getId())
            -> where('is_buy', 0) -> get() -> each(function ($item) use (&$total) {
                $total += $item -> singletotal;
            });

        return view('paypal.checkout', compact('total', 'carts'));
    }



    /**
     * paypal 支付成功
     *
     **/
    public function paySuccess()
    {
        dd('success');
    }

    /**
     *
     *paypal 支付失败
     **/
    public function payFail()
    {
        dd('fail');
    }

    /**
     *按钮api创建订单
     *
     **/
    public function createOrder()
    {
        /**
         * @var $userId 用户id
         * @var $data   创建paypal数据
         **/
        $userId = session() -> getId();
        $data = $this -> service -> createConfigData($userId);
        $provider = new PayPalClient();
        $paypalToken = $provider -> getAccessToken();
        $response = $provider -> createOrder($data);
        dispatch(new CheckOrderJob($response['id'], $userId)) -> delay(now() -> addMinutes(1));
        return response($response);
    }

    /**
     *api捕获订单
     **/
    public function captureOrder($orderId)
    {
        $userId = session()->getId();
        $provider = new PayPalClient();
        $provider -> getAccessToken();
        $response = $provider -> capturePaymentOrder($orderId);
        $this -> service -> handleResponse($response, $userId);
        return $response;
    }
}
