<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Redis;
use Laravel\Scout\Searchable;

class Product extends Model
{
    public $asYouType = true;
    use Searchable;
    use HasFactory;

    protected $imgPath = 'https://www.batteriexpert.com/img/';
    public static $recently = [];
    protected $table = 'product';
    protected $primaryKey = 'pid';
    const PRO_ORDER_GROUP = [
        'id' => 'pid',
        'price' => 'pprice_eu'
    ];
//    protected $connection = "product";

//    public function __construct()
//    {
////        $this->table = DB::raw( "`battesk3_batterycc.com`.`product`");
//    }

    protected static function booted()
    {
        static ::addGlobalScope('stock', function (Builder $builder) {
            $builder -> where('product.pprice_eu', '>', 0) -> where('product.stock', 'ok')
            ->orderBy('pid','desc');
        });
    }

    public function getTitleAttribute()
    {
        return $this -> jianjie1 . ' ' . $this -> jianjie2;
    }

    public function getJianjie1Attribute($value)
    {
        return explode(' ', $value)[0];
    }


    public function getOkpcodeAttribute($value)
    {
        return $this -> imgPath . $value . '.jpg';
    }

    public function getUrlAttribute()
    {
        return route('detail', [$this -> pid, urlencode($this -> cs), $this -> jianjie1]);
    }

    public function getPriceAttribute()
    {
        return $this -> pprice_eu . symbol();
    }

    public function getPriceOldAttribute()
    {
        return sprintf("%.2f%s", $this -> pprice_eu * oldPriceMul(), symbol());
    }

    public function getImgmoreAttribute($value)
    {
        if (empty($value)) return $value;
        return array_map(function ($val) {
            return $this -> imgPath . $val . '.jpg';
        }, explode('|', $value));
    }

    public function getRepAttribute($value)
    {
        if ($this -> category == 'battery') {
            return explode(' ', $value);
        }
        return $value;
    }

    public function parent()
    {
        return $this -> belongsTo(Category::class, 'category1', 'id');
    }

    /**
     * @note 用户最近浏览的产品
     *
     * @param object|array $res   详情页数据
     * @param integer      $limit 需要的最近浏览的产品个数
     *
     * @return array
     */
    public function recently($res, int $limit = 6)
    {
//        Redis::del('recently');
        $recently = getenv('APP_NAME') . 'recently';
        if (!Redis ::exists($recently)) {
            Redis ::lpush($recently, $res -> pid);
        } else {
            $leng = Redis ::llen($recently);
            $recentlyProducts = Redis ::lrange($recently, 0, -1);
            $key = array_search($res -> pid, $recentlyProducts);
            if ($leng < $limit) {
                if ($key !== false) {
                    Redis ::lrem($recently, intval($key, 10) + 1, $res -> pid);
                    Redis ::lpush($recently, $res -> pid);
                } else {
                    Redis ::lpush($recently, $res -> pid);
                }
//                foreach ($recentlyProducts as $key =>$val){
//                    if ($res->id == json_decode($val)->id){
//                        dd($val);
//                    }
//                }
            } else {
                if ($key !== false) {
                    Redis ::lrem($recently, intval($key, 10) + 1, $res -> pid);
                    Redis ::lpush($recently, $res -> pid);
                } else {
                    Redis ::rpop($recently);
                    Redis ::lpush($recently, $res -> pid);
                }
            }
        }
        return Redis ::lrange($recently, 0, $limit);
    }

    public function getCompAttribute($value)
    {
        $pattern = "/src=[\'|\"]([a-zA-Z0-9\_\-]{1,}\/)/i";
        $imgs = preg_match($pattern, $value, $arr);
        if ($imgs) {
            $replace = "src='" . '/imgorigin/';
            if (isset($arr[1])) $value = preg_replace($pattern, $replace, $value);
        }
        return $value;
    }

    public function scopeSortBy($query, string $sort): void
    {
        if ($sort) {

            switch ($sort) {
                case 'time|desc':
                    $query -> orderBy('pid', 'desc');
                    break;
                case 'price|asc':
                    $query -> orderBy('pprice_eu', 'asc');
                    break;
                case 'price|desc':
                    $query -> orderBy('pprice_eu', 'desc');
                    break;
            }
        } else {
            $query -> orderBy('id', 'desc');
        }
    }

    public function isStock()
    {
        return $this -> stock === 'ok' && $this -> pprice_eu > 0;
    }

    public function isBzq()
    {
        return $this -> category === 'adapter' && $this -> bzq && $this -> bzq != 1;
    }

    public function toSearchableArray()
    {
        return [
            'pid' => $this -> pid,
            'okpcode' => $this -> okpcode,
            'pcode' => $this -> pcode,
            'jianjie1' => $this -> getAttribute('jianjie1'),
            'comp' => $this -> comp
        ];
    }

    public function scopeOrder($query, $param)
    {
        if (!$param) {
            return $query -> orderBy('pid', 'desc');
        }
       $data = $this->handleOrder($param);
        return $query -> orderBY($data['column'], $data['type']);
    }

    public function handleOrder($param):array
    {
        $param = explode('|', $param);
        $column = self::PRO_ORDER_GROUP[$param[0]];
        $type = $param[1];
        return compact('column','type');
    }
}
