<?php

namespace App\Models\Service;

use App\Models\Cart;
use App\Models\Paypal;
use App\Models\Product;
use Illuminate\Database\Eloquent\Collection;
use Illuminate\Support\Str;
use Srmklive\PayPal\Services\PayPal as PayPalClient;

class PaypalService
{
    protected $model;

    public function __construct(Paypal $paypal)
    {
        $this -> model = $paypal;
    }

    /**
     * @note 生成paypal amount items配置 存放产品信息
     *
     * @param string $userId 购物车id
     **/
    public function createItemsAmount(string $userId): array
    {
        $items = [];
        $amount = [];
        $total = 0;
        $currency = config('paypal.currency');
        $carts = Cart ::query() -> where('session_id', $userId) -> where('is_buy', 0) -> get();
        foreach ($carts as $cart) {
            $item = [];
            $product = $cart -> product;
            $item["name"] = $cart -> brand . ' ' . $cart -> jian;
            $item['description'] = $cart -> jian . $product -> jianjie2;
            $item['sku'] = $product -> pcode;
            $item['unit_amount'] = [
                'currency_code' => $currency,
                'value' => $product -> pprice_eu,
            ];
            $item['tax'] = [
                'currency_code' => $currency,
                'value' => 0.00,
            ];
            $item['quantity'] = $cart -> numbers;
            $item['category'] = 'PHYSICAL_GOODS';
            $items[] = $item;
            $total += $cart -> singletotal;
        }
        $amount = [
            'currency_code' => $currency,
            'value' => $total,
            'breakdown' =>
                [
                    'item_total' => [
                        'currency_code' => $currency,
                        'value' => $total,
                    ],

                    'shipping' => [
                        'currency_code' => $currency,
                        'value' => '0.00'
                    ],
                    'handling' => [
                        'currency_code' => $currency,
                        'value' => '0.00'
                    ],
                    'tax_total' => [
                        'currency_code' => $currency,
                        'value' => '0.00'
                    ],
                    'shipping_discount' => [
                        'currency_code' => $currency,
                        'value' => '0.00'
                    ],
                ],
        ];
        return compact('items', 'amount');
    }

    /**
     *
     * @note 生成用户购买地址
     *
     * @param array $info 用户信息
     **/
    public function createShipping(array $info = []): array
    {
        if (!$info) {
            return [];
        }
        return [
            'method' => 'United States Postal Service',
            'name' =>
                [
                    'full_name' => $info['name'],
                ],
            'address' =>
                [
                    'address_line_1' => $info['address1'],
                    'address_line_2' => $info['address2'] ?? '',
                    'admin_area_2' => $info['city'],
                    'admin_area_1' => $info['state'],
                    'postal_code' => $info['postal'],
                    'country_code' => $info['country'],
                ]
        ];
    }

    /**
     * @note 生成付款配置文件
     **/

    public function createConfigData(string $userId, array $info = []): array
    {
        $config = $this -> createItemsAmount($userId);
        $items = $config['items'];
        $amount = $config['amount'];
        $shipping = $this -> createShipping($info);
        if ($shipping) {
            return [
                'intent' => 'CAPTURE',
                'application_context' => [
                    'return_url' => route('successTransaction'),
                    'cancel_url' => route('cancelTransaction'),
                    'brand_name' => config('paypal.brand_name'),
                    'locale' => config('paypal.locale'),
                    'landing_page' => 'BILLING',
                    'user_action' => 'PAY_NOW',
                    'shipping_preference' => 'SET_PROVIDED_ADDRESS',
                ],
                'purchase_units' => [
                    0 => [
                        'reference_id' => 'PUHF',
                        'description' => 'Sporting Goods',
                        'custom_id' => 'CUST-HighFashions',
                        'soft_descriptor' => 'HighFashions',
                        'amount' => $amount,
                        'items' => $items,
                        'shipping' => $shipping
                    ]
                ],
            ];
        }
        $data = [
            'intent' => 'CAPTURE',
            'application_context' => [
                'return_url' => route('successTransaction'),
                'cancel_url' => route('cancelTransaction'),
                'brand_name' => config('paypal.brand_name'),
                'locale' => config('paypal.locale'),
                'landing_page' => 'BILLING',
                'user_action' => 'PAY_NOW',
                'shipping_preference' => 'GET_FROM_FILE',
            ],
            'purchase_units' => [
                0 => [
                    'reference_id' => 'PUHF',
                    'description' => 'Sporting Goods',
                    'custom_id' => 'CUST-HighFashions',
                    'soft_descriptor' => 'HighFashions',
                    'amount' => $amount,
                    'items' => $items,
                ]
            ],
        ];
        return $data;
    }

    /**
     * @note 付款成功后数据入库
     * @note 具体参数可查看paypal文档 https://developer.paypal.com/docs/api/orders/v2/#orders_capture
     *
     * @param array  $response paypal server 返回的数据
     * @param string $userId   用户id
     *
     **/
    public function handleResponse(array $response, string $userId)
    {
        /**
         * @var $data ['trans_id'] paypal交易号
         * @var $data ['payer_id'] paypal用户id
         * @var $data ['local_id'] 本地生成订单id
         * @var $data ['order_id'] 订单id可查询订单
         *
         **/
        $data = [];
        $carts = Cart ::query() -> with('product') -> where('session_id', $userId) -> where('is_buy', 0)
            -> get();
        $description = '';
        $shipping = $response['purchase_units'][0]['shipping'];
        $amount = $response['purchase_units'][0]['payments']['captures'][0]['amount'];
        $data['session_id'] = $userId;
        $data['trans_id'] = $response['purchase_units'][0]['payments']['captures'][0]['id'];
        $data['payer_id'] = $response['payer']['payer_id'];
        $data['local_id'] = now() -> format('Ymd') . Str ::random(8);
        $data['order_id'] = $response['id'];
        $data['name'] = $shipping['name']['full_name'];
        $data['phone'] = $response['payment_source']['paypal']['phone_number']['national_number'];
        $data['email'] = $response['payment_source']['paypal']['email_address'];
        $data['postal'] = $shipping['address']['postal_code'];
        $data['country'] = $shipping['address']['country_code'];
        $data['state'] = $shipping['address']['admin_area_1'];
        $data['city'] = $shipping['address']['admin_area_2'];
        $data['street1'] = $shipping['address']['address_line_1'];
        $data['street2'] = $shipping['address']['address_line_2'] ?? '';
        $data['ip'] = request() -> ip();
        $data['total'] = $amount['value'];
        $data['currency'] = $amount['currency_code'];
        foreach ($carts as $cart) {
            $description .= $cart -> jian . $cart -> brand . ' quantity(' . $cart -> numbers . ')' . '| ';
        }
        $data['des'] = $description;
        sendPaypal([
            'domain' => 'www.denchi-pc.com',
            'session_id' => $data['session_id'],
            'trans_id' => $data['trans_id'],
            'local_id' => $data['local_id'],
            'order_id' => $data['order_id'],
            'name' => $data['name'],
            'phone' => $data['phone'],
            'email' => $data['email'],
            'postal' => $data['postal'],
            'country' => $data['country'],
            'state' => $data['state'],
            'city' => $data['city'],
            'street1' => $data['street1'],
            'street2' => $data['street2'],
            'total' => $data['total'],
            'ip' => $data['ip'],
            'currency' => $data['currency'],
            'description' => $data['des'],
        ],'http://us08-01.test/order');
        $this -> model -> create($data);
    }

    /**
     *
     * 根据数据库产品创建paypal产品
     **/
    public function createProduct($item): array
    {
        return [
            "name" => trim($item -> title),
            "description" => trim($item -> title),
            "type" => "SERVICE",
            "category" => "SOFTWARE",
            "image_url" => trim($item -> okpcode),
            "home_url" => trim($item -> url),
        ];
    }

    public function updateProduct(array $product): array
    {
        $data = [];

        unset($product['type']);
        unset($product['category']);
        foreach ($product as $k => $v) {
            $data[] = $this -> generateUpdateData($k, $v);
        }
        return $data;
    }

    public function generateUpdateData(string $column, string $value, string $op = 'replace')
    {
        return [
            'op' => $op,
            'path' => '/' . $column,
            'value' => $value
        ];
    }
}
