<?php

namespace App\Providers;

use App\Models\Cart;
use App\Models\Product;
use App\Models\Search;
use App\Models\Service\CategoryService;
use App\Models\Service\ProductService;
use Illuminate\Pagination\Paginator;
use Illuminate\View\View;
use Illuminate\Support\ServiceProvider;

class AppServiceProvider extends ServiceProvider
{
    /**
     * Register any application services.
     *
     * @return void
     */
    public function register()
    {
        //header头部分类

        \Illuminate\Support\Facades\View ::composer('layouts.__header', function (View $view) {
            $category = app(CategoryService::class);
            $categories = $category -> header();
            $leftCategories = $category -> importantCate();
            $view -> with(['nav' => $categories, 'leftNav' => $leftCategories]);
        });
        \Illuminate\Support\Facades\View ::composer('categories.__left', function (View $view) {
            $product = app(ProductService::class);
            $category = app(CategoryService::class);
            $new = $product -> getNewProducts(8);
            $brands = $category -> getBrands();
            $tags = Search ::query() -> selectRaw('name,max(url)as url,count(name)as nums') -> groupBy('name') -> orderBy('nums', 'desc') -> limit(12) -> get();
            $recently = $product -> getProductRecently(6);
            $view -> with([
                'leftProducts' => $new,
                'leftBrands' => $brands,
                'leftTags' => $tags,
                'leftRecently' => $recently
            ]);
        });
        \Illuminate\Support\Facades\View ::composer('layouts.__footer', function (View $view) {
            $product = app(ProductService::class);
            $category = app(CategoryService::class);
            $recently = $product -> getProductRecently(5);
            $tags = Search ::query() -> selectRaw('name,max(url)as url,count(name)as nums') -> groupBy('name') -> orderBy('nums', 'desc') -> limit(12) -> get();
            $ids = Cart ::query() -> selectRaw('max(id) as id,product_id') -> groupBy('product_id')
                -> limit(5)
                -> orderBy('id', 'desc') -> get() -> pluck('product_id');
            $products = Product ::query() -> whereIn('pid', $ids) -> get();
            $brands = $category -> getBrands(5);
            $view -> with([
                'footerRecently' => $recently,
                'footerTags' => $tags,
                'footerPro' => $products,
                'footerBrands' => $brands
            ]);
        });

    }

    /**
     * Bootstrap any application services.
     *
     * @return void
     */
    public function boot()
    {
        Paginator ::defaultView('vendor.pagination.custom');

    }
}
